import argparse
import giftsnippet


def main():
    parser = argparse.ArgumentParser(description="Replace gift-snippets in your gift file with highlighted code images")
    parser.add_argument('file', help='Provide a gift file to replace gift-snippets with highlighted code images')
    args = parser.parse_args()

    try:
        giftsnippet.process_gift_file(args.file)
    except Exception as e:
        print("An error occured: " + getattr(e, 'message', repr(e)))





from .gift import find_snippet_lines, replace_lines, get_base_dir, process_gift_file
from .highlight import get_data_uri_snippet, get_lexer_from_filetype
from .image import get_data_uri_image, transform_image_to_data_uri
